@@ -27,6 +27,7 @@
 #include <libtracker-common/tracker-utils.h>
 
 #include <libtracker-extract/tracker-extract.h>
+#include <libtracker-extract/tracker-utils.h>
 
 #define NMM_PREFIX TRACKER_NMM_PREFIX
 #define NFO_PREFIX TRACKER_NFO_PREFIX
@@ -38,7 +39,9 @@
 #define RDF_TYPE RDF_PREFIX "type"
 
 static void
-tracker_extract_xine (const gchar *uri, TrackerSparqlBuilder *metadata)
+tracker_extract_xine (const gchar          *uri,
+                      TrackerSparqlBuilder *preupdate,
+		      TrackerSparqlBuilder *metadata)
 {
 	xine_t            *xine_base;
 	xine_audio_port_t *audio_port;
@@ -108,9 +111,13 @@ tracker_extract_xine (const gchar *uri, TrackerSparqlBuilder *metadata)
 	if (author) {
 		gchar *canonical_uri = tracker_uri_printf_escaped ("urn:artist:%s", author);
 
-		tracker_sparql_builder_subject_iri (metadata, canonical_uri);
-		tracker_sparql_builder_predicate (metadata, "a");
-		tracker_sparql_builder_object (metadata, "nmm:Artist");
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+
+		tracker_sparql_builder_subject_iri (preupdate, canonical_uri);
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nmm:Artist");
+
+		tracker_sparql_builder_insert_close (preupdate);
 
 		g_free (canonical_uri);
 	}
@@ -119,16 +126,19 @@ tracker_extract_xine (const gchar *uri, TrackerSparqlBuilder *metadata)
 	if (album) {
 		gchar *canonical_uri = tracker_uri_printf_escaped ("urn:album:%s", album);
 
-		tracker_sparql_builder_subject_iri (metadata, canonical_uri);
-		tracker_sparql_builder_predicate (metadata, "a");
-		tracker_sparql_builder_object (metadata, "nmm:MusicAlbum");
-		tracker_sparql_builder_predicate (metadata, "nmm:albumTitle");
-		tracker_sparql_builder_object_unvalidated (metadata, album);
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+
+		tracker_sparql_builder_subject_iri (preupdate, canonical_uri);
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nmm:MusicAlbum");
+		tracker_sparql_builder_predicate (preupdate, "nmm:albumTitle");
+		tracker_sparql_builder_object_unvalidated (preupdate, album);
+
+		tracker_sparql_builder_insert_close (preupdate);
 
 		g_free (canonical_uri);
 	}
 
-	tracker_sparql_builder_subject_iri (metadata, uri);
 	tracker_sparql_builder_predicate (metadata, "a");
 
 	if (has_video) {
