@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Edward Duffy (eduffy@gmail.com)
  * Copyright (C) 2008, Nokia
@@ -27,7 +26,8 @@
 #include <libtracker-common/tracker-ontology.h>
 #include <libtracker-common/tracker-utils.h>
 
-#include "tracker-main.h"
+#include <libtracker-extract/tracker-extract.h>
+#include <libtracker-extract/tracker-utils.h>
 
 #define NMM_PREFIX TRACKER_NMM_PREFIX
 #define NFO_PREFIX TRACKER_NFO_PREFIX
@@ -54,8 +54,9 @@ static const gchar *tags[][2] = {
 	{ NULL,                                         NULL                    }
 };
 
-static void extract_totem (const gchar *uri,
-                           TrackerSparqlBuilder   *metadata);
+static void extract_totem (const gchar          *uri,
+                           TrackerSparqlBuilder *preupdate,
+                           TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData data[] = {
 	{ "audio/*", extract_totem },
@@ -75,8 +76,9 @@ metadata_write_foreach (gpointer key,
 }
 
 static void
-extract_totem (const gchar *uri,
-               TrackerSparqlBuilder   *metadata)
+extract_totem (const gchar          *uri,
+               TrackerSparqlBuilder *preupdate,
+               TrackerSparqlBuilder *metadata)
 {
 	gchar *argv[3];
 	gchar *totem;
@@ -125,29 +127,36 @@ extract_totem (const gchar *uri,
 		}
 
 		if (artist) {
-			tracker_sparql_builder_subject_iri (metadata, artist_uri);
-			tracker_sparql_builder_predicate (metadata, "a");
-			tracker_sparql_builder_object (metadata, "nmm:Artist");
+			tracker_sparql_builder_insert_open (preupdate, NULL);
+
+			tracker_sparql_builder_subject_iri (preupdate, artist_uri);
+			tracker_sparql_builder_predicate (preupdate, "a");
+			tracker_sparql_builder_object (preupdate, "nmm:Artist");
 
 			if (has_video) {
-				tracker_sparql_builder_object (metadata, "nmm:director");
+				tracker_sparql_builder_object (preupdate, "nmm:director");
 			} else {
-				tracker_sparql_builder_object (metadata, "nmm:composer");
+				tracker_sparql_builder_object (preupdate, "nmm:composer");
 			}
 
-			tracker_sparql_builder_predicate (metadata, "nmm:artistName");
-			tracker_sparql_builder_object_unvalidated (metadata, artist);
+			tracker_sparql_builder_predicate (preupdate, "nmm:artistName");
+			tracker_sparql_builder_object_unvalidated (preupdate, artist);
+
+			tracker_sparql_builder_insert_close (preupdate);
 		}
 
 		if (album) {
-			tracker_sparql_builder_subject_iri (metadata, album_uri);
-			tracker_sparql_builder_predicate (metadata, "a");
-			tracker_sparql_builder_object (metadata, "nmm:MusicAlbum");
-			tracker_sparql_builder_predicate (metadata, "nmm:albumTitle");
-			tracker_sparql_builder_object_unvalidated (metadata, album);
+			tracker_sparql_builder_insert_open (preupdate, NULL);
+
+			tracker_sparql_builder_subject_iri (preupdate, album_uri);
+			tracker_sparql_builder_predicate (preupdate, "a");
+			tracker_sparql_builder_object (preupdate, "nmm:MusicAlbum");
+			tracker_sparql_builder_predicate (preupdate, "nmm:albumTitle");
+			tracker_sparql_builder_object_unvalidated (preupdate, album);
+
+			tracker_sparql_builder_insert_close (preupdate);
 		}
 
-		tracker_sparql_builder_subject_iri (metadata, uri);
 		tracker_sparql_builder_predicate (metadata, "a");
 
 		if (has_video) {
@@ -184,7 +193,7 @@ extract_totem (const gchar *uri,
 }
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return data;
 }
